@@ -287,7 +287,8 @@ class TestGoogleCodeWikiImportController(TestController, TestCase):
         """Mount Google Code importer on the SVN admin controller"""
         super(TestGoogleCodeWikiImportController, self).setUp()
         from forgewiki.wiki_main import WikiAdminController
-        WikiAdminController._importer = GoogleCodeWikiImportController()
+        WikiAdminController._importer = \
+                GoogleCodeWikiImportController(GoogleCodeWikiImporter())
 
     @with_wiki
     def test_index(self):
